==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/WebButtonDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebButtonBaseDescriptionMetadata } from "./WebButtonBaseDescriptionMetadata";
import { WebButtonDescription } from "./WebButtonDescription";
/**
 * @hidden
 */
var WebButtonDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebButtonDescriptionMetadata, _super);
    function WebButtonDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebButtonDescriptionMetadata.b = function (a) {
        if (WebButtonDescriptionMetadata.a == null) {
            WebButtonDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebButtonDescriptionMetadata.c(WebButtonDescriptionMetadata.a);
        }
        if (a.g(WebButtonDescriptionMetadata.a)) {
            return;
        }
        a.s(WebButtonDescriptionMetadata.a);
    };
    WebButtonDescriptionMetadata.c = function (a) {
        WebButtonBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:Button");
        a.item("Variant", "ExportedType:string:ButtonVariant");
        a.item("Variant@names", "Flat;Contained;Outlined;Fab");
    };
    WebButtonDescriptionMetadata.d = function (a) {
        WebButtonDescriptionMetadata.b(a);
        a.u("WebButton", function () { return new WebButtonDescription(); });
        a.t("WebButton", WebButtonDescriptionMetadata.a);
    };
    WebButtonDescriptionMetadata.$t = markType(WebButtonDescriptionMetadata, 'WebButtonDescriptionMetadata');
    WebButtonDescriptionMetadata.a = null;
    return WebButtonDescriptionMetadata;
}(Base));
export { WebButtonDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebButtonDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebButtonBaseDescriptionMetadata } from "./WebButtonBaseDescriptionMetadata";
import { WebButtonDescription } from "./WebButtonDescription";
/**
 * @hidden
 */
var WebButtonDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebButtonDescriptionMetadata, _super);
    function WebButtonDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebButtonDescriptionMetadata.b = function (a) {
        if (WebButtonDescriptionMetadata.a == null) {
            WebButtonDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebButtonDescriptionMetadata.c(WebButtonDescriptionMetadata.a);
        }
        if (a.j(WebButtonDescriptionMetadata.a)) {
            return;
        }
        a.y(WebButtonDescriptionMetadata.a);
    };
    WebButtonDescriptionMetadata.c = function (a) {
        WebButtonBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:Button");
        a.item("__tagNameWC", "String:igc-button");
        a.item("Variant", "ExportedType:string:ButtonVariant");
        a.item("Variant@names", "Flat;Contained;Outlined;Fab");
    };
    WebButtonDescriptionMetadata.d = function (a) {
        WebButtonDescriptionMetadata.b(a);
        a.aa("WebButton", function () { return new WebButtonDescription(); });
        a.z("WebButton", WebButtonDescriptionMetadata.a);
    };
    WebButtonDescriptionMetadata.$t = markType(WebButtonDescriptionMetadata, 'WebButtonDescriptionMetadata');
    WebButtonDescriptionMetadata.a = null;
    return WebButtonDescriptionMetadata;
}(Base));
export { WebButtonDescriptionMetadata };
